package
Version:
v0.0.4
Opens a new window with list of versions in this module.
Published: Apr 30, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Result struct {
Stdout []byte
Stderr []byte
ExitCode int
}
Result contains captured command output.
RunError includes command details and captured stderr for failed runs.
Runner executes external commands and always captures stdout/stderr.
NewRunner creates a command runner for a binary.
Run executes a command and captures both stdout and stderr.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.