package
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Apr 15, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Build constructs and marshals a GitHub Actions matrix JSON from a
comma-separated list of OS values and a CodeQL CLI version string.
type Entry struct {
OS string `json:"os"`
CodeQLCLI string `json:"codeql_cli"`
}
Entry is a single cell in a GitHub Actions CI matrix.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.