archive

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Overview

Package archive provides helpers for extracting and creating archive files.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ExtractTarGz

func ExtractTarGz(archivePath, destDir string) error

ExtractTarGz extracts a .tar.gz archive into destDir. Path traversal entries are rejected.

func ExtractZip

func ExtractZip(src, installDir string) error

ExtractZip extracts the zip archive at src into installDir. Path traversal entries are rejected.

Types

This section is empty.

Jump to