Documentation
¶
Index ¶
- func GenerateNewQuery(opts *GenerateQueryOptions) error
- func InitWorkspace(base, codeqlVersion string, overwriteExisting bool) (*config.QLTConfig, error)
- func RunCompile(base, pack string, threads int) error
- func RunPackInstall(base string) error
- func RunQuery(base, queryName, database, lang, pack, format, output, additionalPacks string, ...) error
- type GenerateQueryOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateNewQuery ¶ added in v0.0.3
func GenerateNewQuery(opts *GenerateQueryOptions) error
func InitWorkspace ¶
InitWorkspace initializes a CodeQL query workspace under base. It writes codeql-workspace.yml and optionally updates qlt.conf.json when useBundle is set.
func RunCompile ¶
RunCompile compiles all .ql files under the resolved search root using `codeql query compile`.
func RunPackInstall ¶
RunPackInstall resolves qlpacks under the target path using `codeql pack ls` and runs `codeql pack install` for each pack whose dependencies are not fully cached. Deps are checked via `codeql pack resolve-dependencies` and `codeql resolve packs` before triggering an install.
Types ¶
Click to show internal directories.
Click to hide internal directories.