query

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func InitWorkspace

func InitWorkspace(base, scope, codeqlVersion string, overwriteExisting bool) (*config.QLTConfig, error)

InitWorkspace initializes a CodeQL query workspace under base. It writes codeql-workspace.yml and optionally updates qlt.conf.json when useBundle or scope is set.

func RunCompile

func RunCompile(base, lang, pack string, threads int) error

RunCompile compiles all .ql files under the resolved search root using `codeql query compile`.

func RunPackInstall

func RunPackInstall(base, lang string) error

RunPackInstall resolves qlpacks under the target path using `codeql pack ls` and runs `codeql pack install` for each resolved qlpack.yml.

func RunQuery

func RunQuery(base, queryName, database, lang, pack, format, output, additionalPacks string, threads int) error

RunQuery resolves the query file and runs `codeql database analyze`.

Types

This section is empty.

Jump to