Documentation
¶
Index ¶
- func InitWorkspace(base, scope, codeqlVersion string, overwriteExisting bool) (*config.QLTConfig, error)
- func RunCompile(base, lang, pack string, threads int) error
- func RunPackInstall(base, lang string) error
- func RunQuery(base, queryName, database, lang, pack, format, output, additionalPacks string, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InitWorkspace ¶
func InitWorkspace(base, scope, codeqlVersion string, overwriteExisting bool) (*config.QLTConfig, error)
InitWorkspace initializes a CodeQL query workspace under base. It writes codeql-workspace.yml and optionally updates qlt.conf.json when useBundle or scope is set.
func RunCompile ¶
RunCompile compiles all .ql files under the resolved search root using `codeql query compile`.
func RunPackInstall ¶
RunPackInstall resolves qlpacks under the target path using `codeql pack ls` and runs `codeql pack install` for each resolved qlpack.yml.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.